#!/bin/bash
#SBATCH -A bsc32
#SBATCH -J compile_ifs_bundle
#SBATCH -N 1
#SBATCH -n 1
#SBATCH -c 112
#SBATCH --exclusive
#SBATCH --time=02:00:00
#SBATCH --output=compile_ifs_bundle_%j.txt

# Check args:
if [[ $# -ne 2 ]]; then
    echo "Usage: $0 <install_dir> <arch_setup>"
    exit 1
fi

source ../bash_utils/*.sh
INSTALL_DIR=$1
ARCH_SETUP=$2

info "using arch folder from $ARCH_SETUP"

# Move to running dir
cd $INSTALL_DIR


# Configure & compile:

export IFS_BUNDLE_SKIP_FESOM=1

export IFS_BUNDLE_RAPS_GIT="ssh://git@git.ecmwf.int/~esp0512/raps-optimizations.git"
export IFS_BUNDLE_RAPS_VERSION="features/mn5"

export IFS_BUNDLE_IFS_SOURCE_GIT="ssh://git@git.ecmwf.int/~pacp/ifs-source-de.git"
export IFS_BUNDLE_IFS_SOURCE_VERSION="MN5"
export IFS_BUNDLE_ATLAS_ORCA_CMAKE="ENABLE_RETRIEVE_ORCA_DATA=OFF ENABLE_INSTALL_ORCA_DATA=ON"

info "Creating & configuring the bundle"
./ifs-bundle create &> log.create
./ifs-bundle build --arch ${ARCH_SETUP} --with-single-precision \
            --with-double-precision-nemo --nemo-version=V40 \
            --nemo-grid-config=eORCA1_GO8_Z75 --nemo-ice-config=SI3 \
            --with-multio-for-nemo-sglexe --dry-run --verbose \
            --nemovar-grid-config=ORCA1_Z42 --nemovar-ver=DEV &> log.build

cd build
./configure.sh &> log.configure 
source env.sh && make -j 60 &> log.make 
