#!/bin/bash

if [[ $# -ne 4 ]]; then
    echo "Usage: $0 <source (tar.gz)> <install_dir> <arch_setup> <running_method>"
    echo -e "\tarch setup: path like arch/eurohpc/mn5-gpp/default"
    echo -e "\trunning method: interactive | mn5_queue"
    exit 1
fi

source ../bash_utils/*.sh

UTILS_DIR=$(pwd -P)
SOURCE_FILE=$1
INSTALL_DIR=$2
ARCH_SETUP=$3
RUN_METHOD=$4

# 1. Check install dir:
info "Checking installation dir... "
if [ ! -d "$INSTALL_DIR" ]; then
    info "Install dir not found. Creating"
    mkdir -p $INSTALL_DIR
fi
success "DONE"
cd $INSTALL_DIR

# 2. Uncompress sources:
info "Uncompressing sources into $INSTALL_DIR DIR... "
if [ ! -f $SOURCE_FILE ]; then
    fatal "Unable to find ${SOURCE_FILE}."
fi
if [ -d "source" ]; then
    info "Found source folder, SKIPPING"
else
    tar -xf $SOURCE_FILE
    success "DONE"
fi

# 2. Check arch_file presence
[ -d $ARCH_SETUP ] || fatal "Unable to find ${ARCH_SETUP}. $(ls -la arch)"

# 3. Submit compilation script:

case "$RUN_METHOD" in
    interactive)
        info "Running compilation in ${INSTALL_DIR}"
        bash ${UTILS_DIR}/compile-mn5-gpp.slurm ${INSTALL_DIR} ${ARCH_SETUP}
    ;;
    *)
        info "Submitting compilation into $RUN_METHOD queue"
        sbatch  --qos=${RUN_METHOD} \
                ${UTILS_DIR}/compile-mn5-gpp.slurm ${INSTALL_DIR} ${ARCH_SETUP}
    ;;
esac
